--
-- Tests -- examples from Tutorial - Chapter 4
--

-- Create Table (4.3)
CREATE TABLE weather (
   city		varchar(80),
   temp_lo	int,		-- low temperature
   temp_hi	int,		-- high temperature
   prcp		real,		-- precipitation
   date		date
);

-- Insert Into (4.4)
INSERT INTO weather VALUES ('San Francisco', 46, 50, 0.25, '1994-11-27');
COPY weather FROM '/usr/lib/pgsql/test/regress/data/weather.data' USING DELIMITERS '|';

-- Queries (4.5)
SELECT * FROM weather;

SELECT * FROM weather
   WHERE city = 'San Francisco'
   AND prcp > 0.0;

SELECT DISTINCT city
   FROM weather
   ORDER BY city;

-- redirecting SELECT queries (4.6)
SELECT * INTO TABLE temp FROM weather;

SELECT * FROM temp;
-- Joins between tables (4.7)
SELECT W1.city, W1.temp_lo AS low, W1.temp_hi AS high,
   W2.city, W2.temp_lo AS low, W2.temp_hi AS high
   FROM weather W1, weather W2
   WHERE W1.temp_lo < W2.temp_lo
   AND W1.temp_hi > W2.temp_hi;

-- Updates (4.8)
UPDATE weather
   SET temp_hi = temp_hi - 2, temp_lo = temp_lo - 2
   WHERE date > '1994-11-28';

SELECT * FROM weather;
-- Deletions (4.9)
DELETE FROM weather WHERE city = 'Hayward';

-- Use aggregate functions (4.10)
SELECT max(temp_lo) FROM weather;

-- this will not work since the aggregate max can't be used in WHERE
SELECT city FROM weather WHERE temp_lo = max(temp_lo);

SELECT city FROM weather
   WHERE temp_lo = (SELECT max(temp_lo) FROM weather);

SELECT city, max(temp_lo)
   FROM weather
   GROUP BY city
   HAVING min(temp_lo) < 0;

SELECT city, max(temp_lo)
   FROM weather
   WHERE city like 'P%'
   GROUP BY city
   HAVING min(temp_lo) < 0;

-- Drop Table
DROP TABLE weather;
